# pinecone-client
The Pinecone python client

For more information, see the docs at https://www.pinecone.io/docs/

## Installation

Install a released version from pip:
```shell
pip install pinecone-client
```

Or the latest development version:
```shell
pip install git+https://git@github.com/pinecone-io/pinecone-python-client.git
```

Or a specific development version:
```shell
pip install git+https://git@github.com/pinecone-io/pinecone-python-client.git
pip install git+https://git@github.com/pinecone-io/pinecone-python-client.git@example-branch-name
pip install git+https://git@github.com/pinecone-io/pinecone-python-client.git@259deff
```